@@ -18,7 +18,7 @@ log.setLevel(logging.DEBUG)
 def get_yandex_image(name):
     info = SQL.get_con_info()
     link = 'https://yandex.ru/images/search?text=' + name[0] + '%20' + name[1] + '%20' + name[2]
-    html = f.get_selenium_html(link, chromium=info[-4], driver=info[-3], params=info[-5])
+    html = f.get_selenium_html(link, chromium=info['chromium_path'], driver=info['chromedriver_path'], params=info['use_chromium'])
     soup = BeautifulSoup(html, 'html.parser')
     soup = soup.find('a', class_='serp-item__link')
     soup = soup.find('img').get('src')
